@@ -304,7 +304,7 @@ NFSFileHandle NFSProtocol::getFileHandle(QString path)
       parentFH.setInvalid();
       return parentFH;
    }
-   //check wether we have this filehandle cached
+   //check whether we have this filehandle cached
    //the filehandles of the exported root dirs are always in the cache
    if (m_handleCache.find(path)!=m_handleCache.end())
    {
@@ -1144,7 +1144,7 @@ void NFSProtocol::get( const KUrl& url )
       readArgs.offset+=offset;
       if (offset>0)
       {
-         array.setRawData(readRes.readres_u.reply.data.data_val, offset);
+         array = QByteArray::fromRawData(readRes.readres_u.reply.data.data_val, offset);
          data( array );
          array.clear();
 
